#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Aug  9 20:53:16 2023

@author: ridwanbello

This python script should be run only after running reprod_analysis.do in STATA
"""



####Import Libraries
import os
import pandas as pd
import seaborn as sns
import matplotlib.pyplot as plt
import numpy as np

####Import data
os.chdir('/Users/ridwanbello/Library/CloudStorage/GoogleDrive-ridzy4real@gmail.com/My Drive/Research/Green_hotels/Data/Reproducibility_package')
data = pd.read_stata('hotel_data_for_py.dta')
data = data.loc[data["row_miss_n"]==0,:]


#####FIGURE 2

####Arrange cities in descending order of median price 
price_by_city = data.pivot_table(values='Postedprice',
                                 index='City',
                                 aggfunc=np.median)
price_by_city.reset_index(inplace=True)
price_by_city.sort_values('Postedprice',
                          ascending=False,
                          inplace=True)
cat_order = list(price_by_city.City)

####Plot price distribution by city
sns.set_style("darkgrid")
sns.set_context("notebook")
g = sns.catplot(y="Postedprice",
            x="City",
            kind="box", 
            data=data,
            sym="",
            whis=[5,95],
            order=cat_order,
            color='gray'
            )
g.set(ylabel="Median hotel room rate (USD per night)", xlabel=None)
plt.xticks(rotation=90)
plt.show()
g.savefig("Figure_2.png")

######END OF FIGURE 2


######FIGURE 3
data.replace({"Sust_property":{0:"Hotels with no ecolabel",1:"Hotels with ecolabel"}}, inplace=True)

####Arrange cities in descending order of median price 
price_by_city = data.pivot_table(values='Postedprice',
                                 index='City',
                                 columns='Sust_property',
                                 aggfunc=np.median)
price_by_city.reset_index(inplace=True)
price_by_city.sort_values('Hotels with no ecolabel',
                          ascending=True,
                          inplace=True)
cat_order = list(price_by_city.City)

####Generate median room rate by city and ecolabel
g = sns.barplot(data = data,
            x="City",
            y="Postedprice",
            estimator=np.median,
            hue="Sust_property",
            order=cat_order,
            errorbar=None)
g.set(ylabel="Median hotel room rate (USD per night)", xlabel=None)
plt.xticks(rotation=90)
plt.show()
fig = g.figure
fig.savefig("Figure_3.png")

######END OF FIGURE 3


#####TABLE 4
#Generate counts of ecolabeled and unlabeled hotels by city
count_by_city = data.pivot_table(values='Name',
                                 index='City',
                                 columns='Sust_property',
                                 aggfunc='count')

#Add ecolabeled and unlabeled hotels to get all hotels, by city
count_by_city['All hotels'] =  count_by_city['Hotels with no ecolabel'] + count_by_city['Hotels with ecolabel']

#Compute share of ecolabeled hotels, by city
def share_ecolabeled(x,y):
    return round(((x/y)*100),0)

count_by_city['Share of ecolabel adopters'] = np.vectorize(share_ecolabeled)(count_by_city['Hotels with ecolabel'],count_by_city['All hotels'])
count_by_city.sort_values('All hotels', ascending=False, inplace=True)
count_by_city.reset_index(inplace=True)

#Add TCI rank to the table
top_city_data = pd.read_stata('Top_100_cities_destination_index.dta')
final_df = count_by_city.merge(top_city_data[['City','TCIRank']],
                    on='City',
                    how='left')
final_df.rename(columns={'TCIRank':'Tourism competitiveness rank'}, inplace=True)

#Reorder columns as displayed in the paper.
final_df = final_df[['City', 'All hotels', 'Hotels with no ecolabel', 'Hotels with ecolabel', 'Share of ecolabel adopters', 'Tourism competitiveness rank']]
######END OF TABLE 4
