**load data
cd "/Users/ridwanbello/Library/CloudStorage/GoogleDrive-ridzy4real@gmail.com/My Drive/Research/Green_hotels/Data/Reproducibility_package"
use hotel_data.dta
decode city, gen(City)
merge m:1 City using "Top_100_cities_destination_index.dta"
tab City if _merge==3
tab City if _merge==1
egen Rating_std = std(Rating)
egen Shareofecolabeladopters_std = std(Shareofecolabeladopters)


**These cities are not in the top 100 cities
drop if City == "Geneva" | City == "Oslo"

**Generate missing data by variable
egen row_miss_n = rowmiss(Postedprice Sust_property property brand_bin review_log Rating_std Access_to_Subway Breakfast_option Prepay_not_needed Free_cancel_option)

**Run descriptives
tabstat Postedprice Sust_property property brand_bin Review_count Rating Distance_km Access_to_Subway Breakfast_option Prepay_not_needed Free_cancel_option if row_miss_n==0, stat(n mean min median max) col(stat)
tab city Sust_property if row_miss_n==0

**Specify global variables
*With distance to city centre
global x_list_log i.property i.brand_bin review_log Rating_std dist_log i.Access_to_Subway i.Breakfast_option i.Prepay_not_needed i.Free_cancel_option

*Without distance to city centre
global x_list_log_2 i.property i.brand_bin review_log Rating_std i.Access_to_Subway i.Breakfast_option i.Prepay_not_needed i.Free_cancel_option 

** Check and install required packages
local packages outreg2 coefplot
foreach package in `packages' {
	capture which `package'
	if _rc == 111 {
		ssc install `package'
	}
}


**Determinants of room rate, full sample
reg price_log Sust_property
outreg2 using price_det, excel dec(3)
reg price_log Sust_property $x_list_log_2
outreg2 using price_det, excel dec(3)
reg price_log Sust_property $x_list_log_2 i.city
outreg2 using price_det, excel dec(3)
reg price_log Sust_property $x_list_log i.city
outreg2 using price_det, excel dec(3)



**Determinants of room rate, city-specific sample
reg price_log Sust_property $x_list_log if City=="Venice"
est store Venice
reg price_log Sust_property $x_list_log if City=="Stockholm"
est store Stockholm
reg price_log Sust_property $x_list_log if City=="Amsterdam"
est store Amsterdam
reg price_log Sust_property $x_list_log if City=="Brussels"
est store Brussels
reg price_log Sust_property $x_list_log if City=="Copenhagen"
est store Copenhagen
reg price_log Sust_property $x_list_log if City=="Vienna"
est store Vienna
reg price_log Sust_property $x_list_log if City=="Barcelona"
est store Barcelona
reg price_log Sust_property $x_list_log if City=="Lisbon"
est store Lisbon
reg price_log Sust_property $x_list_log if City=="Paris"
est store Paris
reg price_log Sust_property $x_list_log_2 if City=="London"
est store London
** Amsterdam = 1, Barcelona = 2, Brussels = 3, Copenhagen = 4, Lisbon = 6, London = 7, Paris = 9, Stockholm = 10, Venice = 11, Vienna = 12

**Plot coefficients
coefplot Venice Stockholm Amsterdam Brussels Copenhagen Vienna Barcelona Lisbon Paris London, keep(Sust_property) yline(0, lcolor(black) lwidth(thin) lpattern(dash)) ciopts(recast(rcap)) mlabel format(%9.2g) mlabgap(*0.2) vertical
graph save "Figure_4"

**Heterogeneity analysis
reg price_log Sust_property $x_list_log i.city
outreg2 using hetero, excel dec(3)

reg price_log i.Sust_property##c.Shareofecolabeladopters_std $x_list_log_2 i.city, vce(cluster city)
outreg2 using hetero, excel dec(3)
margins, dydx(Sust_property) at(Shareofecolabeladopters_std=(-4(1)4)) vsquish noestimcheck
marginsplot, recast(line) recastci(rarea) yline(0)
graph save "Figure_5"


reg price_log i.Sust_property##c.TCIRank $x_list_log_2 i.city, vce(cluster city)
outreg2 using hetero, excel dec(3)
margins, dydx(Sust_property) at(TCIRank =(0(5)50)) vsquish noestimcheck
marginsplot, recast(line) recastci(rarea) yline(0)
graph save "Figure_6"

**Save data for further graphing in Python
save "hotel_data_for_py.dta", replace
